Clarify QuicSession::CloseStreamInner() parameters.

The parameter "locally_reset" only indicates whether a Rst has been sent. So I changed it to a clearer name.

gfe-relnote: no behavior change, not protected.
PiperOrigin-RevId: 293034521
Change-Id: Id5db771349c329cacc54833a07a414e39bc91d2e
diff --git a/quic/core/quic_session.h b/quic/core/quic_session.h
index a6501c2..c6fae2f 100644
--- a/quic/core/quic_session.h
+++ b/quic/core/quic_session.h
@@ -514,9 +514,9 @@
   // as a transport parameter, or in the most recent MAX_STREAMS frame.
   QuicStreamCount GetAdvertisedMaxIncomingBidirectionalStreams() const;
 
-  // Performs the work required to close |stream_id|.  If |locally_reset|
-  // then the stream has been reset by this endpoint, not by the peer.
-  virtual void CloseStreamInner(QuicStreamId stream_id, bool locally_reset);
+  // Performs the work required to close |stream_id|.  If |rst_sent| then a
+  // Reset Stream frame has already been sent for this stream.
+  virtual void CloseStreamInner(QuicStreamId stream_id, bool rst_sent);
 
   // When a stream is closed locally, it may not yet know how many bytes the
   // peer sent on that stream.